@@ -2,7 +2,6 @@ import threading
 
 from wialon.api import Wialon, WialonError
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
 
 from .errors import (
     WialonLogoutError,
@@ -17,6 +16,7 @@ class WialonSession:
         self,
         token: str | None = None,
         sid: str | None = None,
+        uid: str | None = None,
         scheme: str = "https",
         host: str = "hst-api.wialon.com",
         port: int = 443,
@@ -33,13 +33,10 @@ class WialonSession:
         :rtype: :py:obj:`None`
 
         """
-        if not hasattr(settings, "WIALON_TOKEN"):
-            raise ImproperlyConfigured("'WIALON_TOKEN' setting is required.")
-        if not hasattr(settings, "WIALON_ADMIN_ID"):
-            raise ImproperlyConfigured("'WIALON_ADMIN_ID' setting is required.")
 
         self.wialon_api = Wialon(scheme=scheme, host=host, port=port, sid=sid)
         self.token = token
+        self.login_id = uid
         self._username = None
         self._gis_sid = None
         self._hw_gp_ip = None
@@ -252,8 +249,6 @@ class WialonSession:
 
         :param token: An active Wialon API token.
         :type token: :py:obj:`str`
-        :param user_id: A user to operate as in the Wialon API session.
-        :type user_id: :py:obj:`str` | :py:obj:`None`
         :param flags: A login response flag integer.
         :type flags: :py:obj:`int`
         :raises WialonLoginError: If the login fails.
@@ -321,9 +316,6 @@ class WialonSessionManager:
         return cls._instance
 
     def get_session(self, sid: str | None = None) -> WialonSession:
-        if not hasattr(settings, "WIALON_TOKEN"):
-            raise ImproperlyConfigured("'WIALON_TOKEN' setting is required.")
-
         with self._lock:
             if not self._session or not self._session.active:
                 self._session = WialonSession(sid=sid)
